import { Suspense } from "react";


import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import RelatedProjectsClient from "@/components/sections/projects/related-projects";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { getClient } from "@/lib/react-query";
import { cn } from "@/lib/utils";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchhProjectBySlug } from "@/servers/actions/project-action";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";
import { getLocale } from "next-intl/server";
import Image from "next/image";



export default async function ProjectDetailsPage({
	params,
}: {
	params: Promise<{ slug: string[] }>;
}) {
	console.log("hiiiii");
	const { slug } = await params;
	const locale = await getLocale() as Locale;

	console.log("slug: ", slug);

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/projects",
			label: {
				en: "Projects",
				ar: "المشاريع",
			},
		}
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["project"], queryFn: () => fetchhProjectBySlug(slug?.[0]) }),

	]);

	const _data = queryClient.getQueryData<any>(["project"]);
	console.log("data: ", _data);
	const _project = _data?.data;
	console.log("project: ", _project);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block">
					<Header />
					<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
						<PageBreadcrump
							locale={locale}
							subtitle={{
								en: "Company Projects",
								ar: "مشاريع الشركة",
							}}
							title={{
								en: _project?.title_ar,
								ar: _project?.title_en,
							}}
							breadcrumbItems={breadcrumbItems}
							backgroundUrl="/project.png"
						/>
						<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-14">
							<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
								<div className="flex flex-col items-start justify-between p-24 gap-28 md:flex-row">
									<div className={cn("flex flex-[30%] flex-col gap-5")}>
										<p className="text-justify text-base text-[#3B3B3B]">
											{locale === "ar" ? _project?.description_ar : _project?.description_en}
										</p>
									</div>

									<div
										className="relative aspect-square h-[540px] w-[540px] overflow-hidden rounded-lg bg-gray-100"
										style={{
											boxShadow: "0px 4px 4px 0px #00000040",
										}}
									>
										<Image
											src={ImageBaseUrl + _project?.thumbnail?.image_path}
											alt={_project?.thumbnail?.name}
											fill
											className="object-cover"
										/>
									</div>
								</div>

								<hr />
								<RelatedProjectsClient />
							</Suspense>
						</div>
						<Footer />
					</Suspense>
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}
